@@ -44,6 +44,7 @@ public:
     void setForceNotLaptop(bool force);
 
     static KScreen::ModePtr biggestMode(const KScreen::ModeList &modes);
+    qreal bestScaleForOutput(const KScreen::OutputPtr &output);
 
 Q_SIGNALS:
     void ready();
@@ -54,15 +55,14 @@ private:
 
     KScreen::ConfigPtr fallbackIfNeeded(const KScreen::ConfigPtr &config);
 
-    void cloneScreens(KScreen::OutputList &connectedOutputs);
-    void laptop(KScreen::OutputList &connectedOutputs);
-    void singleOutput(KScreen::OutputList &connectedOutputs);
-    void extendToRight(KScreen::OutputList &connectedOutputs);
+    void cloneScreens(const KScreen::ConfigPtr &config);
+    void laptop(KScreen::ConfigPtr &config);
+    void singleOutput(KScreen::ConfigPtr &config);
+    void extendToRight(KScreen::ConfigPtr &config, KScreen::OutputList usableOutputs);
 
     void initializeOutput(const KScreen::OutputPtr &output, KScreen::Config::Features features);
     KScreen::ModePtr bestModeForSize(const KScreen::ModeList &modes, const QSize &size);
     KScreen::ModePtr bestModeForOutput(const KScreen::OutputPtr &output);
-    qreal bestScaleForOutput(const KScreen::OutputPtr &output);
 
     KScreen::OutputPtr biggestOutput(const KScreen::OutputList &connectedOutputs);
     KScreen::OutputPtr embeddedOutput(const KScreen::OutputList &connectedOutputs);
